"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _vue = _interopRequireWildcard(require("vue"));

var _modal = _interopRequireDefault(require("ant-design-vue/es/modal"));

var _types = require("./types");

var _Loading = _interopRequireDefault(require("../Loading"));

require("./style.less");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

/**
 * 图片组件
 */
var _default2 = {
  name: 'EImage',
  components: {
    AModal: _modal["default"],
    ELoading: _Loading["default"]
  },
  props: _types.ImageProps,
  data: function data() {
    return {
      previewModalVisible: false,
      // 预览模态是否显示
      isLoading: true,
      // 是否在加载中
      loadImageSuccess: false
    };
  },
  methods: {
    /**
     * 获取图片的显示绝对路径
     * @returns {*}
     * @private
     */
    _getImageTargetUrl: function _getImageTargetUrl() {
      return this.$props.url;
    },

    /**
     * loading结束
     * @param loadImageSuccess 图片加载是否成功
     * @private
     */
    _loadingFinish: function _loadingFinish() {
      var loadImageSuccess = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : true;

      if (this.$data.isLoading) {
        this.$data.isLoading = false;
        this.$data.loadImageSuccess = loadImageSuccess;
      }
    },

    /**
     * 预览图片
     */
    previewImage: function previewImage() {
      this.$data.previewModalVisible = true;
    },

    /**
     * 隐藏预览
     */
    hidePreview: function hidePreview() {
      this.$data.previewModalVisible = false;
    },

    /**
     * 渲染预览的模态
     * @return {*}
     */
    renderPreviewModal: function renderPreviewModal() {
      var _this = this;

      var props = {
        visible: this.$data.previewModalVisible,
        footer: null,
        maskClosable: true,
        width: '960px'
      };
      return _vue.createVNode(_vue.resolveComponent("a-modal"), _vue.mergeProps({
        props: props
      }, {
        "onCancel": this.hidePreview
      }), {
        "default": function _default() {
          return [_vue.createVNode("div", {
            "class": "preview-img-wrapper"
          }, [_vue.createVNode("img", {
            "src": _this._getImageTargetUrl(),
            "class": "preview-img",
            "alt": ""
          }, null)])];
        }
      });
    }
  },
  render: function render() {
    var _this2 = this;

    var clickToPreview = this.$props.clickToPreview;
    var showDom = null;

    if (this.$data.isLoading) {
      // 展示loading
      showDom = [_vue.createVNode(_vue.resolveComponent("e-loading"), null, null), _vue.createVNode("img", {
        "class": "loading-img",
        "src": this._getImageTargetUrl(),
        "onLoad": function onLoad() {
          _this2._loadingFinish();
        }
      }, null)];
    } else if (this.$data.loadImageSuccess) {
      return _vue.createVNode("div", {
        "class": "oss-image-wrapper",
        "onClick": this.previewImage
      }, [_vue.createVNode("img", {
        "src": this._getImageTargetUrl()
      }, null), clickToPreview ? this.renderPreviewModal() : null]);
    } else {
      showDom = '图片加载失败';
    }

    return _vue.createVNode("div", {
      "class": "oss-image-wrapper"
    }, [showDom]);
  }
};
exports["default"] = _default2;