"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _vue = _interopRequireWildcard(require("vue"));

var _isPromise = _interopRequireDefault(require("is-promise"));

var _select2 = _interopRequireDefault(require("ant-design-vue/es/select"));

var _types = _interopRequireDefault(require("./types"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

/**
 * @Date: 2020/11/23 9:20 下午
 * @Author: Fioanna
 * @Description: 建议下拉框
 */
var ASelectOption = _select2["default"].Option;
var _default2 = {
  name: 'ESuggestSelect',
  props: _types["default"],
  components: {
    ASelect: _select2["default"],
    ASelectOption: ASelectOption
  },
  data: function data() {
    return {
      // 当前是否在请求数据
      isSearching: false,
      // 搜索关键词
      searchKey: '',
      // 建议搜索框列表
      suggestList: []
    };
  },
  computed: {
    // 默认值
    valueObj: function valueObj() {
      return this.labelInValue && this.value ? {
        value: this.value,
        label: this.label
      } : this.value;
    }
  },
  model: {
    prop: 'value',
    event: 'change'
  },
  methods: {
    /**
     * 输入后获取建议列表
     * @param key
     * @private
     */
    _search: function _search(key) {
      var _this = this;

      this.$data.searchKey = key;

      if (!this.$data.isSearching && key) {
        this.$data.isSearching = true;
        var result = this.$props.loadList ? this.$props.loadList(key) : this.getSuggestList(key);

        if ((0, _isPromise["default"])(result)) {
          result.then(function (list) {
            // 当前的搜索和发送协议的搜索一直的时候才修改list
            if (_this.$data.searchKey === key) {
              if (list && list.length > 0) {
                _this.$data.suggestList = list;
              }
            }
          })["catch"](function () {})["finally"](function () {
            _this.$data.isSearching = false;
          });
        }
      }
    },

    /**
     * 点击某一项选择
     * @param item
     * @private
     */
    _select: function _select(item) {
      var value = item[this.$props.valueName];

      if (this.$props.value !== value) {
        // 选中的改变才发送事件
        var label = item[this.$props.labelName];
        this.$emit('change', value, label, item);
      }
    },

    /**
     * 获取建议列表，可继承
     * @param key 输入的文字
     * @returns {Promise<*[]>}
     */
    // eslint-disable-next-line
    getSuggestList: function getSuggestList(key) {
      return Promise.resolve([]);
    },

    /**
     * 清空建议列表
     * 主要给外部调用的
     */
    resetSuggestList: function resetSuggestList() {
      this.$data.suggestList = [];
      this.$emit('change', undefined, undefined);
    }
  },
  render: function render() {
    var _this2 = this;

    var _this$$props = this.$props,
        disabled = _this$$props.disabled,
        placeholder = _this$$props.placeholder,
        labelInValue = _this$$props.labelInValue,
        valueName = _this$$props.valueName,
        labelName = _this$$props.labelName;
    var contentDom = null;

    if (this.$data.searchKey) {
      // 输入了文字的就展示数据列表，或者无数据
      if (this.$data.suggestList.length > 0) {
        contentDom = this.$data.suggestList.map(function (option) {
          var value = option[valueName];
          var label = option[labelName];
          return _vue.createVNode(_vue.resolveComponent("a-select-option"), {
            "disabled": option.disabled,
            "key": value,
            "value": value,
            "title": label,
            "onClick": function onClick() {
              _this2._select(option);
            }
          }, {
            "default": function _default() {
              return [label];
            }
          });
        });
      }
    } else {
      // 未输入提示输入
      contentDom = _vue.createVNode("span", {
        "slot": "notFoundContent"
      }, [placeholder]);
    }

    return _vue.createVNode(_vue.resolveComponent("a-select"), {
      "showArrow": false,
      "filterOption": false,
      "defaultActiveFirstOption": false,
      "showSearch": true,
      "disabled": disabled,
      "placeholder": placeholder,
      "labelInValue": labelInValue,
      "value": this.valueObj,
      "onSearch": this._search
    }, {
      "default": function _default() {
        return [contentDom];
      }
    });
  }
};
exports["default"] = _default2;